summaryrefslogtreecommitdiff
path: root/bfd/syms.c
diff options
context:
space:
mode:
Diffstat (limited to 'bfd/syms.c')
-rw-r--r--bfd/syms.c15
1 files changed, 11 insertions, 4 deletions
diff --git a/bfd/syms.c b/bfd/syms.c
index 9d425684d9..8831b9257c 100644
--- a/bfd/syms.c
+++ b/bfd/syms.c
@@ -989,10 +989,17 @@ _bfd_stab_section_find_nearest_line (bfd *abfd,
if (info->stabsec == NULL || info->strsec == NULL)
{
- /* No stabs debugging information. Set *pinfo so that we
- can return quickly in the info != NULL case above. */
- *pinfo = info;
- return TRUE;
+ /* Try SOM section names. */
+ info->stabsec = bfd_get_section_by_name (abfd, "$GDB_SYMBOLS$");
+ info->strsec = bfd_get_section_by_name (abfd, "$GDB_STRINGS$");
+
+ if (info->stabsec == NULL || info->strsec == NULL)
+ {
+ /* No stabs debugging information. Set *pinfo so that we
+ can return quickly in the info != NULL case above. */
+ *pinfo = info;
+ return TRUE;
+ }
}
stabsize = (info->stabsec->rawsize